@@ -446,19 +446,10 @@ GetPW(pwp, number)
     register char *nstr;
     register char *bptr;
     char buffer[NUMWORDS * MAXWORDLEN];
-    static uint32_t prevblock = 0xffffffff;
     uint32_t thisblock;
 
     thisblock = number / NUMWORDS;
 
-    if (prevblock == thisblock)
-    {
-#if DEBUG
-	fprintf(stderr, "returning (%s)\n", pwp->data_get[number % NUMWORDS]);
-#endif
-	return (pwp->data_get[number % NUMWORDS]);
-    }
-
     if (_PWIsBroken64(pwp->ifp))
     {
        uint64_t datum64;
@@ -526,8 +517,6 @@ GetPW(pwp, number)
 	return NULL;
     }
 
-    prevblock = thisblock;
-
     bptr = buffer;
 
     for (ostr = pwp->data_get[0]; (*(ostr++) = *(bptr++)); /* nothing */ );
